from .types import LogAttrs as LogAttrs, LogType as LogType, Serialazable as Serialazable

def Any(key: str, value: Serialazable) -> LogType: ...
def Error(value: Exception) -> LogType: ...
def String(key: str, value: str) -> LogType: ...
def Int(key: str, value: int) -> LogType: ...
def Float(key: str, value: float) -> LogType: ...
